Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(473)

Unified Diff: public/web/WebView.h

Issue 179013002: Add WebDocument::clearFocusedElement (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/web/tests/WebFrameTest.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/web/WebView.h
diff --git a/public/web/WebView.h b/public/web/WebView.h
index 3fffa2809143a003d66428a4eed8759de3e25bdf..c2653e725fdb020d4bcfb5d9d58ce9faf58a6542 100644
--- a/public/web/WebView.h
+++ b/public/web/WebView.h
@@ -180,9 +180,12 @@ public:
// Focus the first (last if reverse is true) focusable node.
virtual void setInitialFocus(bool reverse) = 0;
// Clears the focused node (and selection if a text field is focused)
// to ensure that a text field on the page is not eating keystrokes we
// send it.
+ virtual void clearFocusedElement() = 0;
+
+ // Deprecated API. Will be removed soon..
virtual void clearFocusedNode() = 0;
// Scrolls the node currently in focus into view.
« no previous file with comments | « Source/web/tests/WebFrameTest.cpp ('k') | no next file » | no next file with comments »
@@ -180,9 +180,12 @@ public:
// Focus the first (last if reverse is true) focusable node.
virtual void setInitialFocus(bool reverse) = 0;
- // Clears the focused node (and selection if a text field is focused)
+ // Clears the focused element (and selection if a text field is focused)
// to ensure that a text field on the page is not eating keystrokes we
// send it.

Powered by Google App Engine
This is Rietveld 408576698